==> summerd-sdk-1.0.61.tgz: package/server/middlewares/proxy.js <==
const path = require('path')
const httpProxy = require('http-proxy')

function getProxyConfig () {
  const configPath = path.resolve(`${process.cwd()}/server.config.js`)

  delete require.cache[configPath]

  const serverConfig = require(configPath)

  return serverConfig.proxy
}

const apiProxy = httpProxy.createProxyServer({
  changeOrigin: true,
})

// 代理错误处理, 否则当代理出错,服务会crash
apiProxy.on('error', (err, req, res, target) => {
  const errMsg = `Error when requesting to api host '${target.host}', please check it!`
  console.log(`${errMsg}\n${err.stack}`)
  res.writeHead(500, {
    'Content-Type': 'text/plain',
  })
  res.end(errMsg)
})

apiProxy.on('proxyReq', (proxyReq, req, res, proxyOptions) => {
  req._proxyStartTimestamp = Date.now()
  req._proxyOptions = proxyOptions
})

apiProxy.on('proxyRes', (proxyRes, req) => {
  const target = req._proxyOptions.target
  const location = [target.protocol, '//', target.host, proxyRes.req.path].join('')
  console.log(
    `Proxy request '${location}' completed(${proxyRes.statusCode}), costing ${Date.now() - req._proxyStartTimestamp}ms.`)
})

module.exports = function proxyMiddleware (req, res, next) {
  const url = req.url
  const proxyConfig = getProxyConfig()
  let proxyTarget = null
  
  for (const [prefix, target] of Object.entries(proxyConfig)) {
    if (url.startsWith(prefix)) {
      proxyTarget = target
      console.log(`Proxy Found: '${prefix}' => '${proxyTarget}${prefix}`)
      break
    }
  }

  if (!proxyTarget) {
    console.log('Proxy NOT FOUND, skipped')
    return next()
  }

  return apiProxy.web(req, res, {
    target: proxyTarget,
  })
}

==> summerd-sdk-1.2.20.tgz: package/server/middlewares/proxy.js <==
const path = require('path')
const httpProxy = require('http-proxy')

function getProxyConfig () {
  const configPath = path.resolve(`${process.cwd()}/server.config.js`)

  delete require.cache[configPath]

  const serverConfig = require(configPath)

  return serverConfig.proxy
}

const apiProxy = httpProxy.createProxyServer({
  changeOrigin: true,
})

// 代理错误处理, 否则当代理出错,服务会crash
apiProxy.on('error', (err, req, res, target) => {
  const errMsg = `Error when requesting to api host '${target.host}', please check it!`
  console.log(`${errMsg}\n${err.stack}`)
  res.writeHead(500, {
    'Content-Type': 'text/plain',
  })
  res.end(errMsg)
})

apiProxy.on('proxyReq', (proxyReq, req, res, proxyOptions) => {
  req._proxyStartTimestamp = Date.now()
  req._proxyOptions = proxyOptions
})

apiProxy.on('proxyRes', (proxyRes, req) => {
  const target = req._proxyOptions.target
  const location = [target.protocol, '//', target.host, proxyRes.req.path].join('')
  console.log(
    `Proxy request '${location}' completed(${proxyRes.statusCode}), costing ${Date.now() - req._proxyStartTimestamp}ms.`)
})

module.exports = function proxyMiddleware (req, res, next) {
  const url = req.url
  const proxyConfig = getProxyConfig()
  let proxyTarget = null
  
  for (const [prefix, target] of Object.entries(proxyConfig)) {
    if (url.startsWith(prefix)) {
      proxyTarget = target
      console.log(`Proxy Found: '${prefix}' => '${proxyTarget}${prefix}'`)
      break
    }
  }

  if (!proxyTarget) {
    console.log('Proxy NOT FOUND, skipped')
    return next()
  }

  return apiProxy.web(req, res, {
    target: proxyTarget,
  })
}
